@@ -1021,7 +1021,12 @@ class Module(object):
         return self.name == other.name and self.path == other.path
 
     def __hash__(self):
-        return hash(f"Module_{self.path}_{self.name}")
+        try:
+            path = self.path
+            name = self.name
+            return hash(f"Module_{path}_{name}")
+        except RecursionError:
+            raise Exception(f"Recursion at {self.name}")
 
     def __init__(self, path, force_name=None):
         self.version = float(current_version())
@@ -1139,11 +1144,6 @@ class Module(object):
     def _get_by_name(cls, name, nocache=False, no_deptree=False):
         from .odoo_config import get_odoo_addons_paths
 
-        if not name:
-            import pudb
-
-            pudb.set_trace()
-
         if isinstance(name, Module):
             name = name.name
         path = None
